@@ -1,13 +1,15 @@
-#import notify2 as notify2
+# import notify2
+import click
 
 
 class LinuxNotification:
 
     def _set_notification(self, message):
         """Set notification for unix system"""
-        print(message)
-        # notify2.init('Rate Alert!')
-        # n = notify2.Notification(current_rate["source"] + " 1 = " + current_rate["target"] + " " + str(current_rate["rate"]))
+        click.echo(message)
+        # notify2.init('Exchange Rate Alert!')
+        # n = notify2.Notification("Rate Alert!", message=(message+" Get that Money!"))
+        # n.set_urgency(notify2.URGENCY_NORMAL)
         # n.show()
 
     def set_notification(self, message):
