@@ -1,16 +1,16 @@
 from win10toast import ToastNotifier
-
+import click
 
 class WindowsNotification:
 
     def _set_notification(self, message):
         """Set notification for windows system"""
-        print(message)
+        click.echo(message)
 
         toaster = ToastNotifier()
         toaster.show_toast("Rate Alert!",
                            message + " Get that Money!",
-                           duration=5)
+                           duration=60)
 
     def set_notification(self, message):
         """Set notification code for windows system"""
